@@ -18,6 +18,8 @@ def process(
     grayscale: bool = False,
     invert: bool = False,
     tosaka: Optional[float] = None,
+    outputrgb: bool = False,
+    noise: Optional[float] = None,
 ) -> str:
     """
     Process Runnner for Command Line Interface
@@ -43,6 +45,8 @@ def process(
         grayscale (bool, optional): Convert to grayscale. Defaults to False.
         invert (bool, optional): Invert color. Defaults to False.
         tosaka (Optional[float], optional): Use Tosaka mode. Defaults to None.
+        outputrgb (bool, optional): Outputs a monochrome image in RGB. Defaults to False.
+        noise (Optional[float], optional): Add Gaussian noise. Defaults to None.
 
     Raises:
         fire.core.FireError: Error that occurs when the specified string is not a path.
@@ -77,6 +81,7 @@ def process(
             image = Image.open(file)
         except UnidentifiedImageError as e:
             raise fire.core.FireError(e)
+        exif = image.getexif()
         retouch = Retouch(
             image=image,
             colorautoadjust=colorautoadjust,
@@ -84,6 +89,8 @@ def process(
             grayscale=grayscale,
             invert=invert,
             tosaka=tosaka,
+            outputrgb=outputrgb,
+            noise=noise,
         )
         saved_image = retouch.process()
         os.makedirs(os.path.join(return_path, "out"), exist_ok=True)
@@ -95,6 +102,7 @@ def process(
             ),
             quality=100,
             subsampling=0,
+            exif=exif,
         )
         print("{0}/{1} done!".format((i + 1), str(len(files_glob))))
 
